#! /usr/bin/env python3
import json
import sys

import requests
from Fucking.fuck import dbcache
from Fucking.fuck import fucking_cmd

url = "http://fanyi.baidu.com/v2transapi"

header = {
    "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_6) AppleWebKit/537.36 \
     (KHTML, like Gecko) Chrome/62.0.3202.94 Safari/537.36",
    "Referer": "http://fanyi.baidu.com/",
    "Origin": "http://fanyi.baidu.com",
    "X-Requested-With": "XMLHttpRequest"
}

formdata = {
    "from": "en",
    "to": "zh",
    "query": "",
    "transtype": "translang",
    "simple_means_flag": "3"
}


def _fetch_local(keyword):
    local_res = dbcache.lookup(keyword)
    if local_res:
        return prettify(local_res)
    else:
        result = parse_data(keyword, _fetch_data(keyword))
        if not result:
            return False
        dbcache.save(result)
        return result


def prettify(local_data):
    data = local_data[0]
    result = {
        "word": data[0],
        "symbols": data[1],
        "means": data[2]
    }
    result.update({"local": True})
    return result


def fetch(keyword):
    web = fucking_cmd.get_cmd()['force'] | fucking_cmd.get_cmd()['update']
    if web:
        data = _fetch_data(keyword)
        return parse_data(keyword, data)
    else:
        return _fetch_local(keyword)


def _fetch_data(keyword):
    formdata['query'] = keyword
    try:
        res = requests.post(url, data=formdata, headers=header)
    except ConnectionError:
        print("Connection error.")
        return False
    return res.text


def parse_data(word, data):
    json_dict = json.loads(data)
    if not json_dict['dict_result']:
        return False
    key = json_dict['dict_result']['simple_means']['symbols']
    hassymbol = 'ph_am' in key[0]
    result = {
        "word": word,
        "symbols": str({'美音': key[0]['ph_am'], "英音": key[0]['ph_en']}) if hassymbol else "False",
        "means": str(key[0]['parts']),
        "local": False
    }
    if fucking_cmd.get_cmd()['update']:
        dbcache.save(result)
    return result


def output(result):
    if not result:
        print("You sure your spell is right?")
        exit(-5)
    if result['local']:
        print("From local cache:\t***%s***" % result['word'])
    else:
        print("From Internet:   \t***%s***" % result['word'])
    try:
        symbols = json.loads(result['symbols'].replace("'", "\""))
        for k, v in symbols.items():
            if v:
                sys.stdout.write("%s: [ %s ]\t" % (k, v))
    except json.decoder.JSONDecodeError:
        sys.stdout.write("音标中含有非法字符!")
    print("")
    means = "{\"means\": %s}" % result['means'].replace("\'", "\"")
    print("释义:")
    for mean in json.loads(means)['means']:
        if 'part' in mean:
            print("\t{0:3}   {1}".format(mean['part'], mean['means']))
        elif 'part_name' in mean:
            print("\t来源于网络的结果:   {0}".format(mean['means']))


def main():
    dbcache.init()
    result = fetch(fucking_cmd.parse_cmd())
    output(result)

if __name__ == "__main__":
    main()



import getopt
import socket
import sys

help_info = {
    "fucking word": "Get the pronunciation and the definition of the `word`. \n\t\t\t\t\t(double quotation marks are "
                    "needed if the `word` is a phrase or a sentence)",
    "fucking -f|--force word": "Force to fetch data from the Internet",
    "fucking -u|--update word": "Update the local cache of the `word`(Has the same effect of the -f)",
    "fucking -p|--ping": "Ping the target to check the connection",
    "fucking -h|--help": "Print this help information"
}
force = 0
update = 0


def get_cmd():
    return {
        "force": force,
        "update": update
    }


def usage():
    m = max(map(len, help_info.keys()))
    print("Usage:")
    for k in help_info:
        print("\t", k.ljust(m), "\t", help_info[k])


def ping():
    try:
        soc = socket.socket()
        res = soc.connect(("fanyi.baidu.com", 80))
    except Exception:
        print("Fail!")
    finally:
        soc.close()
    print("Success!")


def parse_cmd():
    global force
    global update
    opts, args = getopt.getopt(sys.argv[1:], "fuph", ["help", "update", "force", "ping"])

    for val in opts:
        val = val[0]
        if val in ["-h", "--help"]:
            usage()
            exit(0)
        elif val in ["-p", "--ping"]:
            ping()
            exit(0)
        elif val in ["-f", "--force"]:
            force = 1
        elif val in ["-u", "--update"]:
            update = 1

    try:
        word = args[0]
    except IndexError:
        print("Seems like you lose your word?")
        exit(-2)

    return word



import os
import sqlite3 as sql

if os.name == 'nt':
    USER_HOME = os.getenv("HOME") or os.path.expanduser("~")  # Win下获得用户家目录的方法??
elif os.name == 'posix':
    USER_HOME = os.getenv('HOME')

if not USER_HOME:
    USER_HOME = "~"

DB_PATH = os.path.join(USER_HOME, "fucking.db")


def connect():
    try:
        conn = sql.connect(DB_PATH, timeout=3)
    except ConnectionError:
        print("Cannot connect to the database")
        exit(-1)
    return conn


def init():
    if not os.path.exists(DB_PATH):
        print("First run. Initing database...")
        conn = connect()
        for n in range(4):
            conn.execute(
                'CREATE TABLE IF NOT EXISTS diction_{0} (id integer primary key autoincrement not null, \
                  word VARCHAR(255) not null, \
                  symbols VARCHAR(255), \
                  means VARCHAR(255) NOT NULL)'.format(str(n)))
        conn.close()
    else:
        pass


def select(_id, location):
    get_sql = 'SELECT word, symbols, means FROM diction_{0} WHERE id = ?'.format(location)
    conn = connect()
    cursor = conn.cursor()
    cursor.execute(get_sql, _id)
    result = cursor.fetchall()
    cursor.close()
    conn.close()
    return result


def lookup(word):
    part = get_location(word)
    lookup_sql = 'SELECT id FROM diction_{0} WHERE word = ?'.format(part)
    conn = connect()
    cursor = conn.cursor()
    cursor.execute(lookup_sql, (word,))
    _id = cursor.fetchall()
    cursor.close()
    conn.close()
    if _id:
        return select(_id[0], part)
    else:
        return False


def save(info):
    part = get_location(info['word'])
    save_sql = 'INSERT INTO diction_{0} (word, symbols, means) VALUES (?, ?, ?)'.format(part)
    conn = connect()
    cursor = conn.cursor()
    cursor.execute(save_sql, (
        info['word'],
        str(info['symbols']),
        str(info['means'])
    ))
    conn.commit()
    cursor.close()
    conn.close()


def get_location(word):
    asc = ord(word[0])
    if asc in range(97, 103) or asc in range(65, 70):
        return "0"
    if asc in range(103, 109) or asc in range(71, 76):
        return "1"
    if asc in range(109, 116) or asc in range(77, 83):
        return "2"
    if asc in range(116, 123) or asc in range(84, 90):
        return "3"
    else:
        print(asc)
        raise UnknownWordException


class UnknownWordException(BaseException):
    pass



#-*- encoding: UTF-8 -*-
from setuptools import setup, find_packages

VERSION = "1.0.0"

setup(name='fucking',
      version=VERSION,
      description="a python tool which make English word to Chinese using the baidu translate.",
      long_description='Simply, this is a python tool which make English word to Chinese using the baidu translate. The feature is fucking once fetch the meaning of the word, it will save it to the local sqlite database. Then the next time you lookup the word, fucking will directly get the meaning of the word quickly from thr disk cache.',
      classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Natural Language :: Chinese (Simplified)",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3 :: Only",
        "Topic :: Terminals"
      ], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='python3 translate terminal',
      author='justin13',
      author_email='justin13wyx@gmail.com',
      url="https://github.com/Justin13wyx/Python_Tools",
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
        'requests',
      ],
      entry_points={
        'console_scripts':[
            'fucking = Fucking.fucking:main'
        ]
      },
)
